@@ -7,8 +7,7 @@ map = {
     '[global]': {
         #'reactor': 'epoll',
 
-        #'proxy.enabled': '1',
-
+        'proxy.enabled': '1',
         'pid.location': '/tmp/orbited.pid',
         'session.ping_interval': '30',
         'session.ping_timeout': '30'
@@ -49,7 +48,13 @@ def update(**kwargs):
     map.update(kwargs)
     return True
 
-def setup(argv):
+defaultPaths = [
+    os.path.join('/', 'etc', 'orbited.cfg'),
+    os.path.join('/', 'Program Files', 'Orbited', 'etc', 'orbited.cfg'),
+    'orbited.cfg',
+]
+
+def setup(argv, paths=defaultPaths):
     parser = OptionParser()
     parser.add_option(
         "--config",
@@ -66,11 +71,6 @@ def setup(argv):
 
     if not options.config:
         # no config file specified, try to search it.
-        paths = [
-            os.path.join('/', 'etc', 'orbited.cfg'),
-            os.path.join('/', 'Program Files', 'Orbited', 'etc', 'orbited.cfg'),
-            'orbited.cfg',
-        ]
         for path in paths:
             if os.path.exists(path):
                 options.config = path
