@@ -1,3 +1,4 @@
+
 // NOTE: to log/debug with Orbited, there are two methods:
 //          Use firebug 
 //              1) include Orbited.js (and not Log4js)
@@ -257,16 +258,28 @@ Orbited.Loggers.PageLogger = function(name) {
         Orbited.singleton.pageLoggerPane.scrollTop = Orbited.singleton.pageLoggerPane.scrollHeight;
     }
     self.log = function() {
+        if (!self.enabled) { return }
+        var newArgs = [ "log", new Date(), "debug", "<b>" + name + "</b>" ]
+        for (var i = 0; i < arguments.length; ++i) {
+            newArgs.push(arguments[i]);
+        }
+        show(newArgs.join(", "));
     }
     self.debug = function() {
         if (!self.enabled) { return }
-        var newArgs = [ new Date(), "<b>" + name + "</b>" ]
+        var newArgs = [ new Date(), "debug", "<b>" + name + "</b>" ]
         for (var i = 0; i < arguments.length; ++i) {
             newArgs.push(arguments[i]);
         }
         show(newArgs.join(", "));
     }
     self.info = function() {
+        if (!self.enabled) { return }
+        var newArgs = [ new Date(), "info", "<b>" + name + "</b>" ]
+        for (var i = 0; i < arguments.length; ++i) {
+            newArgs.push(arguments[i]);
+        }
+        show(newArgs.join(", "));
     }
     self.warn = function() {
     }    
@@ -361,7 +374,10 @@ var createXHR = function () {
 }
 
 
-
+Orbited.legacy = {}
+//Orbited.web.connect = function() {
+//
+//}
 
 Orbited.CometSession = function() {
     var self = this;
@@ -448,7 +464,7 @@ Orbited.CometSession = function() {
         if (self.readyState != self.READY_STATE_OPEN) {
             throw new Error("Invalid readyState")
         }
-        data = Orbited.base64.encode(data)
+        var data = Orbited.base64.encode(data)
         sendQueue.push([++packetCount, "data", data])
 ;;;     self.logger.debug('sending==', sending);
         if (!sending) {
@@ -539,7 +555,7 @@ Orbited.CometSession = function() {
                 break;
             case 'data':
 ;;;             self.logger.debug('base64 decoding ' + frame.data.length + ' bytes of data')
-                data = Orbited.base64.decode(frame.data)
+                var data = Orbited.base64.decode(frame.data)
 ;;;             self.logger.debug('decode complete');
                 self.onread(data);
                 break;
@@ -588,7 +604,13 @@ Orbited.CometSession = function() {
     var transportOnClose = function() {
 ;;;     self.logger.debug('transportOnClose');
         if (self.readyState < self.READY_STATE_CLOSED) {
-            doClose(Orbited.Statuses.ServerClosedConnection)
+            try {
+                doClose(Orbited.Statuses.ServerClosedConnection)
+            }
+            catch(e) {
+//              Fix for navigation-close
+                return
+            }
         }
     }        
     var encodePackets = function(queue) {
@@ -1158,7 +1180,14 @@ Orbited.CometTransports.XHRStream = function() {
                         }
                         // If we got a 200, then we're in business
                         if (status == 200) {
-                            heartbeatTimer = window.setTimeout(heartbeatTimeout, Orbited.settings.HEARTBEAT_TIMEOUT);
+                            try {
+                                heartbeatTimer = window.setTimeout(heartbeatTimeout, Orbited.settings.HEARTBEAT_TIMEOUT);
+                            }
+                            catch(e) {
+//                               Happens after navigation
+                                 self.close()
+                                 return
+                            }
                             var testtimer = heartbeatTimer;
                         }
                         // Otherwise, case 4 should handle the reconnect,
@@ -1240,7 +1269,7 @@ Orbited.CometTransports.XHRStream = function() {
             }
 //            self.logger.debug('do abort..')
             xhr.abort();
-            window.clearTimeout(heartbeatTimer);            
+            window.clearTimeout(heartbeatTimer);
         }
         else {
 ;;;         self.logger.debug('reconnect do open')
@@ -1303,10 +1332,16 @@ Orbited.CometTransports.XHRStream = function() {
     var receivedHeartbeat = function() {
         window.clearTimeout(heartbeatTimer);
 ;;;     self.logger.debug('clearing heartbeatTimer', heartbeatTimer)
-        heartbeatTimer = window.setTimeout(function() { 
+        try {
+            heartbeatTimer = window.setTimeout(function() { 
 ;;;         self.logger.debug('timer', testtimer, 'did it'); 
-            heartbeatTimeout();
-        }, Orbited.settings.HEARTBEAT_TIMEOUT);
+                heartbeatTimeout();
+            }, Orbited.settings.HEARTBEAT_TIMEOUT);
+        }
+        catch(e) {
+            
+            return
+        }
         var testtimer = heartbeatTimer;
 
 ;;;     self.logger.debug('heartbeatTimer is now', heartbeatTimer)
@@ -1771,6 +1806,7 @@ Orbited.CometTransports.HTMLFile = function() {
         if (self.readyState == 1) {
             throw new Error("Already Connected")
         }
+        self.logger.debug('self.connect', _url)
         url = new Orbited.URL(_url)
         url.path += '/htmlfile'
         url.setQsParameter('frameID', id.toString())
@@ -1786,6 +1822,7 @@ Orbited.CometTransports.HTMLFile = function() {
     }
 
     var doOpen = function(_url) {
+;;;     self.logger.debug('doOpen', _url)
         htmlfile = new ActiveXObject('htmlfile'); // magical microsoft object
         htmlfile.open();
 //        htmlfile.write('<html><script>' + 'document.domain="' + document.domain + '";' + '</script></html>');
@@ -2173,10 +2210,6 @@ Orbited.utf8.encode = function(text) {
     return ret.join("");
 }
 
-
-})();
-
-
 if (!this.JSON) {
 
 // Create a JSON object only if one does not already exist. We create the
@@ -2495,3 +2528,24 @@ replace(/(?:^|:|,)(?:\s*\[)+/g, ''))) {
         };
     }();
 }
+Orbited.JSON = JSON;
+
+
+})();
+
+
+// Try to auto detect the Orbited port and hostname
+(function() {
+try {
+    var scripts = document.getElementsByTagName('script')
+    for (var i = 0; i < scripts.length; ++i) {
+        var script = scripts[0]
+        if (script.src.match('/static/Orbited\.js$')) {
+            var url = new Orbited.URL(script.src)
+            Orbited.settings.hostname = url.domain;
+            Orbited.settings.port = url.port;
+            break
+        }
+    }
+} catch(e) { }
+})()
